# revelation

### Example Slides

<small>Created by [Humberto Rocha](https://github.com/humrochagf)</small>

---

## Brief Description

[revelation](https://github.com/humrochagf/revelation) is a cool way to setup your [reveal.js](https://github.com/hakimel/reveal.js) presentations without the need to edit a monolithic html file and using markdown syntax mixed with some html tags

---

## Examples

The following examples show some of the reveal.js features running on revelation

---

## Headers

# &lt; h1 &gt; tag
## &lt; h2 &gt; tag
###### &lt; h6 &gt; tag

---

## Emphasis

*This text will be italic*
_This will also be italic_

**This text will be bold**
__This will also be bold__

*You **can** combine them*

---

## Unordered List

* Item 1
* Item 2
  * Item 2a
  * Item 2b

---

## Ordered List

1. Item 1
2. Item 2
3. Item 3
   * Item 3a
   * Item 3b

---

## Images

![Python Logo](media/python.png)

---

## Links

http://github.com - automatic!

[GitHub](http://github.com)

---

## Blockquotes

> Always look on the bright side of life

---

## Inline code

I think you should use an
`<addr>` element here instead.

---

## Block Code

```python
def foo():
    if not bar:
        return True
```

---

## Table

| First Header | Second Header |
| ------------ | ------------- |
| Content from cell 1 | Content from cell 2 |
| Content in the first column | Content in the second column |

---

## Equations

<section data-markdown>
$$ J(\theta_0,\theta_1) = \sum_{i=0} $$
</section>

---

## The Lorenz Equations</h2>

<section data-markdown>
\[\begin{aligned} \dot{x} &amp; = \sigma(y-x) \\ \dot{y} &amp; = \rho x - y -
xz \\ \dot{z} &amp; = -\beta z + xy \end{aligned} \]
</section>

---

## Fragment

- Item 1 <!-- .element: class="fragment" data-fragment-index="1" -->
- Item 2 <!-- .element: class="fragment" data-fragment-index="2" -->

---

<!-- .slide: data-background="#8c4738" -->
## Background Color

---

## Vertical Slides

Press down arrow to see the next vertical slide

---~

This is a verticale slide

---

## Useful Links

* [reveal.js docs](https://github.com/hakimel/reveal.js)
* [mastering markdown](https://guides.github.com/features/mastering-markdown/#GitHub-flavored-markdown)

---

# The End
